@@ -5,8 +5,9 @@
 package Date::Language::French;
 
 use Date::Language ();
-use vars qw(@ISA @DoW @DoWs @MoY @MoYs @AMPM @Dsuf %MoY %DoW);
+use vars qw(@ISA @DoW @DoWs @MoY @MoYs @AMPM @Dsuf %MoY %DoW $VERSION);
 @ISA = qw(Date::Language);
+$VERSION = "1.01";
 
 @DoW = qw(dimanche lundi mardi mercredi vendredi samedi);
 @MoY = qw(janvier fvrier mars avril mai juin 
